@@ -3,7 +3,7 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-our $VERSION = '4.1.24';
+our $VERSION = '4.1.25';
 sub version { return $VERSION }
 sub sysname { 'bouncehammer'  }
 sub libname { 'Sisimai'       }
@@ -46,9 +46,7 @@ __END__
 
 =head1 NAME
 
-Sisimai - It's a module for analyzing email bounces and generate structured data
-in a JSON format from parsed bounce messages, is a core module of bounceHammer
-version 4.
+Sisimai - Mail Analyzing Interface for bounce mails.
 
 =head1 SYNOPSIS
 
@@ -56,10 +54,11 @@ version 4.
 
 =head1 DESCRIPTION
 
-Sisimai is a core module of C<bounceHammer> version 4, is a Perl module for 
-analyzing email bounce and generate structured data in a JSON format (YAML is 
+Sisimai is the system formerly known as C<bounceHammer> 4, is a Pelr module for
+analyzing bounce mails and generate structured data in a JSON format (YAML is 
 also available if "YAML" module is installed on your system) from parsed bounce
-messages. C<Sisimai> stands for SISI "Mail Analyzing Interface".
+messages. C<Sisimai> is a coined word: Sisi (the number 4 is pronounced "Si" in
+Japanese) and MAI (acronym of "Mail Analyzing Interface").
 
 =head1 BASIC USAGE
 
@@ -72,13 +71,25 @@ messages like following.
     if( defined $v ) {
         for my $e ( @$v ) {
             print ref $e;                   # Sisimai::Data
-            print $e->recipient->address;   # kijitora@example.jp
+            print ref $e->recipient;        # Sisimai::Address
+            print ref $e->timestamp;        # Sisimai::Time
+
+            print $e->addresser->address;   # shironeko@example.org # From
+            print $e->recipient->address;   # kijitora@example.jp   # To
+            print $e->recipient->host;      # example.jp
+            print $e->deliverystatus;       # 5.1.1
             print $e->reason;               # userunknown
 
             my $h = $e->damn;               # Convert to HASH reference
             my $j = $e->dump('json');       # Convert to JSON string
             my $y = $e->dump('yaml');       # Convert to YAML string
         }
+
+        # Dump entire list as a JSON 
+        use JSON '-convert_blessed_universally';
+        my $json = JSON->new->allow_blessed->convert_blessed;
+
+        printf "%s\n", $json->encode( $v );
     }
 
 =head1 SEE ALSO
@@ -86,6 +97,10 @@ messages like following.
 L<Sisimai::Mail> - Mailbox or Maildir object
 L<Sisimai::Data> - Parsed data object
 
+=head1 REPOSITORY
+
+L<https://github.com/azumakuniyuki/p5-Sisimai> - Sisimai on GitHub
+
 =head1 AUTHOR
 
 azumakuniyuki
