@@ -4,7 +4,6 @@ use strict;
 use warnings;
 use Class::Accessor::Lite;
 use Module::Load '';
-use Time::Piece;
 
 use Sisimai::Address;
 use Sisimai::RFC3463;
@@ -13,24 +12,25 @@ use Sisimai::String;
 use Sisimai::Reason;
 use Sisimai::Rhost;
 use Sisimai::Time;
+use Sisimai::DateTime;
 
 my $rwaccessors = [
     'token',            # (String) Message token/MD5 Hex digest value
-    'lhost',            # (String) local host name
-    'rhost',            # (String) Remote host name
+    'lhost',            # (String) local host name/Local MTA
+    'rhost',            # (String) Remote host name/Remote MTA
     'alias',            # (String) The value of alias(RHS)
     'listid',           # (String) List-Id header of each ML
     'reason',           # (String) Bounce reason
-    'action',           # (String) The value of Action header
+    'action',           # (String) The value of Action: header
     'subject',          # (String) UTF-8 Subject text
-    'timestamp',        # (Time::Piece) Date: in the original message
-    'addresser',        # (Sisimai::Address) From: header in the original message
-    'recipient',        # (Sisimai::Address) Final-Recipient: or To: in the original message
+    'timestamp',        # (Sisimai::Time) Date: header in the original message
+    'addresser',        # (Sisimai::Address) From address
+    'recipient',        # (Sisimai::Address) Recipient address which bounced
     'messageid',        # (String) Message-Id: header
     'smtpagent',        # (String) MTA name
     'smtpcommand',      # (String) The last SMTP command
-    'destination',      # (String) A domain part of the "recipinet"
-    'senderdomain',     # (String) A domain part of the "addresser"
+    'destination',      # (String) The domain part of the "recipinet"
+    'senderdomain',     # (String) The domain part of the "addresser"
     'feedbacktype',     # (String) Feedback Type
     'diagnosticcode',   # (String) Diagnostic-Code: Header
     'diagnostictype',   # (String) The 1st part of Diagnostic-Code: Header
@@ -80,8 +80,8 @@ sub new {
                             $argvs->{'timestamp'} );
 
     TIMESTAMP: {
-        # Create Time::Piece object
-        $thing->{'timestamp'} = localtime Time::Piece->new( $argvs->{'timestamp'} );
+        # Create Sisimai::Time object
+        $thing->{'timestamp'} = localtime Sisimai::Time->new( $argvs->{'timestamp'} );
         $thing->{'timezoneoffset'} = $argvs->{'timezoneoffset'} // '+0000';
     }
 
@@ -205,7 +205,7 @@ sub make {
 
             while( my $v = shift @datevalues ) {
                 # Parse each date value in the array
-                $datestring = Sisimai::Time->parse( $v );
+                $datestring = Sisimai::DateTime->parse( $v );
                 last if $datestring;
             }
 
@@ -214,7 +214,7 @@ sub make {
                 if( $datestring =~ m/\A(.+)\s+([-+]\d{4})\z/ ) {
                     # Wed, 26 Feb 2014 06:05:48 -0500
                     $datestring = $1;
-                    $zoneoffset = Sisimai::Time->tz2second($2);
+                    $zoneoffset = Sisimai::DateTime->tz2second($2);
                     $p->{'timezoneoffset'} = $2;
                 }
             }
@@ -222,7 +222,7 @@ sub make {
             eval {
                 # Convert from the date string to an object then calculate time
                 # zone offset.
-                my $t = Time::Piece->strptime( $datestring, '%a, %d %b %Y %T' );
+                my $t = Sisimai::Time->strptime( $datestring, '%a, %d %b %Y %T' );
                 $p->{'timestamp'} = ( $t->epoch - $zoneoffset ) // undef; 
             };
         }
@@ -230,7 +230,11 @@ sub make {
 
         OTHER_TEXT_HEADERS: {
             # Remove square brackets and curly brackets from the host variable
-            map { $p->{ $_ } =~ y/[]()//d } ( 'rhost', 'lhost' );
+            map { $p->{ $_ } =~ y/[]()//d } ( 'rhost', 'lhost' ); 
+
+            # Remove string before "="
+            map { $p->{ $_ } =~ s/\A.+=// } ( 'rhost', 'lhost' );
+
             for my $e ( 'rhost', 'lhost' ) {
                 # Check space character in each value
                 if( $p->{ $e } =~ m/ / ) {
@@ -360,7 +364,7 @@ Sisimai::Data - Parsed data object
     for my $e ( @$data ) {
         print $e->reason;               # userunknown, mailboxfull, and so on.
         print $e->recipient->address;   # (Sisimai::Address) envelope recipient address
-        print $e->bonced->ymd           # (Time::Piece) Date of bounce
+        print $e->bonced->ymd           # (Sisimai::Time) Date of bounce
     }
 
 =head1 DESCRIPTION
@@ -381,7 +385,7 @@ including Sisimai::Data objects.
         for my $e ( @$data ) {
             print $e->reason;               # userunknown, mailboxfull, and so on.
             print $e->recipient->address;   # (Sisimai::Address) envelope recipient address
-            print $e->timestamp->ymd        # (Time::Piece) Date of the email bounce
+            print $e->timestamp->ymd        # (Sisimai::Time) Date of the email bounce
         }
     }
 
@@ -399,7 +403,7 @@ C<damn> convert the object to a hash reference.
 
 Sisimai::Data have the following properties:
 
-=head2 C<timestamp>(I<Time::Piece>)
+=head2 C<timestamp>(I<Sisimai::Time>)
 
 The value of Date: header of the original message or the bounce message.
 
