@@ -9,6 +9,7 @@ my $RxRFC = {
          Content-Type:[ ]*(?:
               message/delivery-status
              |message/disposition-notification
+             |text/plain;[ ]charset=
              )
         |The[ ]original[ ]message[ ]was[ ]received[ ]at[ ]
         |This[ ]report[ ]relates[ ]to[ ]your[ ]message
@@ -43,7 +44,7 @@ my $RxEMS = qr{(?>                                          # Subject:
     )
 }xi;
 
-sub version     { '4.0.21' };
+sub version     { '4.0.25' };
 sub description { 'Fallback Module for MTAs' };
 sub smtpagent   { 'RFC3464' };
 
@@ -313,7 +314,6 @@ sub scan {
 
     BODY_PARSER_FOR_FALLBACK: {
         # Fallback, parse entire message body
-
         unless( $recipients ) {
             # Failed to get a recipient address at code above
             $match = 1 if $mhead->{'from'}        =~ $RxEMF;
@@ -326,7 +326,6 @@ sub scan {
 
             my $RxSkip = qr{(?>
                  \A[-]+=
-                |\A\\\*
                 |\A[\s\t]+\z
                 |\A\s*--
                 |\A\s+[=]\d+
@@ -343,6 +342,8 @@ sub scan {
                 |\AHere[ ]is[ ]a[ ]copy[ ]of[ ]the[ ]first[ ]part[ ]of[ ]the[ ]message
                 |\AThe[ ]non-delivered[ ]message[ ]is[ ]attached[ ]to[ ]this[ ]message.
                 |\AReceived:\s*
+                |\AReceived-From-MTA:\s*
+                |\AReporting-MTA:\s*
                 |\AReturn-Path:\s*
                 |\AA[ ]copy[ ]of[ ]the[ ]original[ ]message[ ]below[ ]this[ ]line:
                 |Attachment[ ]is[ ]a[ ]copy[ ]of[ ]the[ ]message
@@ -351,6 +352,7 @@ sub scan {
                 |Message[ ]contains[ ].+[ ]file[ ]attachments
                 |Message[ ]text[ ]follows:[ ]
                 |Original[ ]message[ ]follows
+                |The[ ]attachment[ ]contains[ ]the[ ]original[ ]mail[ ]headers
                 |The[ ]first[ ]\d+[ ]lines[ ]
                 |Unsent[ ]Message[ ]below
                 |Your[ ]message[ ]reads[ ][(]in[ ]part[)]:
@@ -360,24 +362,30 @@ sub scan {
             my $RxAddr = qr{(?:
                  \A\s*
                 |\A["].+["]\s*
-                |\ARecipient:\s*
+                |\A\s*Recipient:\s*
                 |\A[ ]*Address:[ ]
                 |addressed[ ]to[ ]
+                |Could[ ]not[ ]be[ ]delivered[ ]to:[ ]
                 |delivered[ ]to[ ]+
                 |delivery[ ]failed:[ ]
+                |Did[ ]not[ ]reach[ ]the[ ]following[ ]recipient:[ ]
                 |Error-for:[ ]+
                 |Failed[ ]Recipient:[ ]
+                |Failed[ ]to[ ]deliver[ ]to[ ]
                 |generated[ ]from[ ]
                 |Intended[ ]recipient:[ ]
                 |Mailbox[ ]is[ ]full:[ ]
                 |RCPT[ ]To:
+                |SMTP[ ]Server[ ][<].+[>][ ]rejected[ ]recipient[ ]
+                |The[ ]following[ ]recipients[ ]returned[ ]permanent[ ]errors:[ ]
+                |The[ ]following[ ]message[ ]to[ ]
                 |Unknown[ ]User:[ ]
                 |undeliverable[ ]to[ ]
                 |Undeliverable[ ]Address:[ ]*
                 |You[ ]sent[ ]mail[ ]to[ ]
                 |Your[ ]message[ ]to[ ]
                 )
-                [<]?([^\s\t\n\r@=]+[@][-.0-9A-Za-z]+[.][0-9A-Za-z]+)[>]?
+                ['"]?[<]?([^\s\t\n\r@=]+[@][-.0-9A-Za-z]+[.][0-9A-Za-z]+)[>]?['"]?
             }xi;
 
             my $b = $dscontents->[ -1 ];
@@ -386,10 +394,10 @@ sub scan {
                 last if $e =~ $RxRFC->{'endof'};
                 last if $e =~ $RxRFC->{'rfc822'};
                 last if $e =~ $RxEnd;
-                last if $e =~ m/\A[*]/;
 
                 next unless length $e;
                 next if $e =~ $RxSkip;
+                next if $e =~ m/\A[*]/;
 
                 if( $e =~ $RxAddr ) {
                     # May be an email address
