@@ -17,7 +17,8 @@ sub index {
     return [ qw|
         Blocked ContentError ExceedLimit Expired Filtered HostUnknown MailboxFull
         MailerError MesgTooBig NetworkError NotAccept OnHold Rejected RelayingDenied
-        NoSpam SecurityError Suspend SystemError SystemFull UserUnknown 
+        SpamDetected SecurityError Suspend SystemError SystemFull UserUnknown 
+        HasMoved
     | ];
 }
 
@@ -39,11 +40,11 @@ sub get {
     my $reasontext = '';
     my $classorder = [
         'MailboxFull', 'MesgTooBig', 'ExceedLimit', 'Suspend', 'UserUnknown', 
-        'Filtered', 'Rejected', 'HostUnknown', 'NoSpam', 'Blocked',
+        'Filtered', 'Rejected', 'HostUnknown', 'SpamDetected', 'Blocked',
     ];
 
-    if( $argvs->diagnostictype eq 'SMTP' ) {
-        # Diagnostic-Code: SMTP; ...
+    if( $argvs->diagnostictype eq 'SMTP' || $argvs->diagnostictype eq '' ) {
+        # Diagnostic-Code: SMTP; ... or empty value
         for my $e ( @$classorder ) {
             # Check the value of Diagnostic-Code: and the value of Status:, it is a
             # deliverystats, with true() method in each Sisimai::Reason::* class.
@@ -101,8 +102,9 @@ sub anotherone {
     my $commandtxt = $argvs->smtpcommand    // '';
     my $reasontext = '';
     my $classorder = [
-        'MailboxFull', 'NoSpam', 'SecurityError', 'SystemError', 'NetworkError', 
-        'Suspend', 'Expired', 'ContentError', 'NotAccept', 'MailerError',
+        'MailboxFull', 'SpamDetected', 'SecurityError', 'SystemError', 
+        'NetworkError', 'Suspend', 'Expired', 'ContentError', 'HasMoved', 
+        'NotAccept', 'MailerError',
     ];
     my $retryingto = __PACKAGE__->retry;
     push @$retryingto, 'userunknown';
@@ -192,7 +194,8 @@ of Sisimai::Data instance.
 
 =head2 C<blocked>
 
-Clienet hostname: the argument of C<HELO/EHLO>, is rejected.
+Rejected SMTP session due to client hostname or IP address or the argument of 
+C<HELO/EHLO>.
 
 =head2 C<contenterror>
 
@@ -212,6 +215,11 @@ Delivery time has expired.
 
 The recipient address rejected at the end of DATA command.
 
+=head2 C<hasmoved>
+
+The recipient address has moved to another address or the value of C<Status>
+header or the value of C<deliverystatus> is 4.1.6 or 5.1.6.
+
 =head2 C<hostunknown>
 
 The host part of the recipient address does not exist or the value of C<Status>
@@ -237,7 +245,8 @@ Remote server does not accept email.
 
 =head2 C<onhold>
 
-Could not detect the reason of bounce.
+Could not detect the reason of bounce or deciding the reason is on hold due to
+lack of error messages.
 
 =head2 C<rejected>
 
@@ -259,7 +268,11 @@ The recipient's mailbox temporary disabled.
 
 =head2 C<networkerror>
 
-Network related errors.
+Network related errors such as DNS look up failure.
+
+=head2 C<spamdetected>
+
+The message was detected as a C<spam>.
 
 =head2 C<systemerror>
 
