@@ -8,20 +8,29 @@ sub match {
     my $class = shift;
     my $argvs = shift // return undef;
     my $regex = qr{(?>
-         access[ ]from[ ]ip[ ]address[ ].+[ ]blocked
+         access[ ]denied[.][ ]IP[ ]name[ ]lookup[ ]failed
+        |access[ ]from[ ]ip[ ]address[ ].+[ ]blocked
+        |cannot[ ]resolve[ ]your[ ]address
         |client[ ]host[ ]rejected:[ ]may[ ]not[ ]be[ ]mail[ ]exchanger
         |confirm[ ]this[ ]mail[ ]server
         |connection[ ](?:
             dropped
+           |rate[ ]limit[ ]exceeded
            |refused[ ]by
            |reset[ ]by[ ]peer
            |was[ ]dropped[ ]by[ ]remote[ ]host
            )
         |domain[ ].+[ ]mismatches[ ]client[ ]ip
         |hosts[ ]with[ ]dynamic[ ]ip
+        |IP[/]domain[ ]reputation[ ]problems
         |is[ ]not[ ]allowed[ ]to[ ]send[ ]mail[ ]from
+        |mail[ ]server[ ]at[ ].+[ ]is[ ]blocked
         |no[ ]access[ ]from[ ]mail[ ]server
-        |sorry[,][ ]your[ ]remotehost[ ]looks[ ]suspiciously[ ]like[ ]spammer
+        |please[ ]use[ ]the[ ]smtp[ ]server[ ]of[ ]your[ ]ISP
+        |sorry,[ ](?:
+             that[ ]domain[ ]isn'?t[ ]in[ ]my[ ]list[ ]of[ ]allowed[ ]rcpthosts
+            |your[ ]remotehost[ ]looks[ ]suspiciously[ ]like[ ]spammer
+            )
         |unresolvable[ ]relay[ ]host[ ]name
         |your[ ](?:
              network[ ]is[ ]temporary[ ]blacklisted
