@@ -44,7 +44,10 @@ sub match {
             |[ ].+[ ]in[ ]name[ ]directory
             )
         |non[- ]?existent[ ]user
-        |not[ ]a[ ]valid[ ]user[ ]here
+        |not[ ](?:
+             a[ ]valid[ ]user[ ]here
+            |a[ ]local[ ]address
+            )
         |rcpt[ ][<].+[>][ ]does[ ]not[ ]exist
         |recipient[ ](?:
              .+[ ]was[ ]not[ ]found[ ]in
@@ -67,6 +70,10 @@ sub match {
             |badrcptto
             |no[ ]mailbox[ ]here[ ]by[ ]that[ ]name
             )
+        |the[ ](?:
+              following[ ]recipients[ ]was[ ]undeliverable
+             |user[']s[ ]email[ ]name[ ]is[ ]not[ ]found
+             )
         |this[ ]address[ ]no[ ]longer[ ]accepts[ ]mail
         |this[ ]email[ ]address[ ]is[ ]wrong[ ]or[ ]no[ ]longer[ ]valid
         |this[ ]user[ ]doesn[']?t[ ]have[ ]a[ ].+[ ]account
@@ -74,12 +81,14 @@ sub match {
              address
             |e[-]?mail[ ]address
             |local[- ]part
+            |mailbox
             |recipient
             |user
             )
         |user[ ](?:
              .+[ ]was[ ]not[ ]found
             |.+[ ]does[ ]not[ ]exist
+            |does[ ]not[ ]exist
             |missing[ ]home[ ]directory
             |not[ ]found     # 550 User not found. See http://mail.bigmir.net/err/2/
             |not[ ]known
