@@ -7,6 +7,7 @@ sub list {
         Data.pm
             Data/JSON.pm
             Data/YAML.pm
+        DateTime.pm
         ISO3166.pm
         MIME.pm
         Mail.pm
@@ -65,11 +66,12 @@ sub list {
             Reason/ExceedLimit.pm
             Reason/Expired.pm
             Reason/Filtered.pm
+            Reason/HasMoved.pm
             Reason/HostUnknown.pm
             Reason/MailboxFull.pm
             Reason/MailerError.pm
             Reason/MesgTooBig.pm
-            Reason/NoSpam.pm
+            Reason/SpamDetected.pm
             Reason/NotAccept.pm
             Reason/NetworkError.pm
             Reason/OnHold.pm
